# Scaffold

![CI](https://github.com/ploomber/scaffold/workflows/CI/badge.svg)


Scaffold creates a complete structure for Data Science projects.

## Usage

Scaffold is not intended to be used directly but rather through the
`ploomber scaffold` command.

[Click here to go to Ploomber's repository.](https://github.com/ploomber/ploomber)

## Setup (for developers)

Requires [Miniconda](https://docs.conda.io/en/latest/miniconda.html).

```sh
pip install invoke
invoke setup
```

## Testing

```sh
invoke test
```
